@@ -1,4 +1,13 @@
-"""DataLad demo extension"""
+# emacs: -*- mode: python; py-indent-offset: 4; tab-width: 4; indent-tabs-mode: nil -*-
+# ex: set sts=4 ts=4 sw=4 noet:
+# ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
+#
+#   See LICENSE file distributed along with the datalad_osf package for the
+#   copyright and license terms.
+#
+# ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
+
+"""DataLad extension for data exchange on the Open Science Framework"""
 
 __docformat__ = 'restructuredtext'
 
@@ -11,6 +20,8 @@ command_suite = (
     # description of the command suite, displayed in cmdline help
     "DataLad extension for OSF support",
     [
+        ('datalad_osf.credentials', 'OSFCredentials',
+            'osf-credentials', 'osf_credentials'),
         # specification of a command, any number of commands can be defined
         (
             # importable module that contains the command implementation
